Index: /CKEditor/trunk/_samples/ajax.html
===================================================================
--- /CKEditor/trunk/_samples/ajax.html	(revision 6335)
+++ /CKEditor/trunk/_samples/ajax.html	(revision 6336)
@@ -6,5 +6,5 @@
 <html xmlns="http://www.w3.org/1999/xhtml">
 <head>
-	<title>Ajax - CKEditor Sample</title>
+	<title>Ajax &mdash; CKEditor Sample</title>
 	<meta content="text/html; charset=utf-8" http-equiv="content-type" />
 	<!-- CKReleaser %REMOVE_LINE%
@@ -52,6 +52,17 @@
 <body>
 	<h1>
-		CKEditor Sample
+		CKEditor Sample &mdash; Create and Destroy Editor Instances for Ajax Applications
 	</h1>
+	<div class="description">
+	<p>
+		This sample shows how to create and destroy CKEditor instances on the fly. After the removal of CKEditor the content created inside the editing
+		area will be displayed in a <code>&lt;div&gt;</code> element.
+	</p>
+	<p>
+		For details of how to create this setup check the source code of this sample page
+		for JavaScript code responsible for the creation and destruction of a CKEditor instance.
+	</p>
+	</div>
+	
 	<!-- This <div> holds alert messages to be display in the sample page. -->
 	<div id="alerts">
@@ -64,4 +75,5 @@
 		</noscript>
 	</div>
+	<p>Click the buttons to create and remove a CKEditor instance.</p>
 	<p>
 		<input onclick="createEditor();" type="button" value="Create Editor" />
@@ -81,5 +93,5 @@
 		<hr />
 		<p>
-			CKEditor - The text editor for Internet - <a href="http://ckeditor.com/">http://ckeditor.com</a>
+			CKEditor - The text editor for the Internet - <a href="http://ckeditor.com/">http://ckeditor.com</a>
 		</p>
 		<p id="copy">
Index: /CKEditor/trunk/_samples/api.html
===================================================================
--- /CKEditor/trunk/_samples/api.html	(revision 6335)
+++ /CKEditor/trunk/_samples/api.html	(revision 6336)
@@ -6,5 +6,5 @@
 <html xmlns="http://www.w3.org/1999/xhtml">
 <head>
-	<title>API usage - CKEditor Sample</title>
+	<title>API Usage &mdash; CKEditor Sample</title>
 	<meta content="text/html; charset=utf-8" http-equiv="content-type" />
 	<!-- CKReleaser %REMOVE_LINE%
@@ -18,10 +18,10 @@
 	//<![CDATA[
 
-// The instanceReady event is fired when an instance of CKEditor has finished
+// The instanceReady event is fired, when an instance of CKEditor has finished
 // its initialization.
 CKEDITOR.on( 'instanceReady', function( ev )
 {
 	// Show the editor name and description in the browser status bar.
-	document.getElementById( 'eMessage' ).innerHTML = '<p>Instance "' + ev.editor.name + '" loaded.<\/p>';
+	document.getElementById( 'eMessage' ).innerHTML = '<p>Instance <code>' + ev.editor.name + '<\/code> loaded.<\/p>';
 
 	// Show this sample buttons.
@@ -38,9 +38,10 @@
 	if ( oEditor.mode == 'wysiwyg' )
 	{
-		// Insert the desired HTML.
+		// Insert HTML code.
+		// http://docs.cksource.com/ckeditor_api/symbols/CKEDITOR.editor.html#insertHtml
 		oEditor.insertHtml( value );
 	}
 	else
-		alert( 'You must be on WYSIWYG mode!' );
+		alert( 'You must be in WYSIWYG mode!' );
 }
 
@@ -55,8 +56,9 @@
 	{
 		// Insert as plain text.
+		// http://docs.cksource.com/ckeditor_api/symbols/CKEDITOR.editor.html#insertText
 		oEditor.insertText( value );
 	}
 	else
-		alert( 'You must be on WYSIWYG mode!' );
+		alert( 'You must be in WYSIWYG mode!' );
 }
 
@@ -67,5 +69,6 @@
 	var value = document.getElementById( 'htmlArea' ).value;
 
-	// Set the editor contents (replace the actual one).
+	// Set editor contents (replace current contents).
+	// http://docs.cksource.com/ckeditor_api/symbols/CKEDITOR.editor.html#setData
 	oEditor.setData( value );
 }
@@ -73,8 +76,9 @@
 function GetContents()
 {
-	// Get the editor instance that we want to interact with.
+	// Get the editor instance that you want to interact with.
 	var oEditor = CKEDITOR.instances.editor1;
 
-	// Get the editor contents
+	// Get editor contents
+	// http://docs.cksource.com/ckeditor_api/symbols/CKEDITOR.editor.html#getData
 	alert( oEditor.getData() );
 }
@@ -89,8 +93,9 @@
 	{
 		// Execute the command.
+		// http://docs.cksource.com/ckeditor_api/symbols/CKEDITOR.editor.html#execCommand
 		oEditor.execCommand( commandName );
 	}
 	else
-		alert( 'You must be on WYSIWYG mode!' );
+		alert( 'You must be in WYSIWYG mode!' );
 }
 
@@ -99,4 +104,7 @@
 	// Get the editor instance that we want to interact with.
 	var oEditor = CKEDITOR.instances.editor1;
+	// Checks whether the current editor contents present changes when compared 
+	// to the contents loaded into the editor at startup
+	// http://docs.cksource.com/ckeditor_api/symbols/CKEDITOR.editor.html#checkDirty
 	alert( oEditor.checkDirty() );
 }
@@ -106,4 +114,6 @@
 	// Get the editor instance that we want to interact with.
 	var oEditor = CKEDITOR.instances.editor1;
+	// Resets the "dirty state" of the editor (see CheckDirty())
+	// http://docs.cksource.com/ckeditor_api/symbols/CKEDITOR.editor.html#resetDirty
 	oEditor.resetDirty();
 	alert( 'The "IsDirty" status has been reset' );
@@ -116,6 +126,17 @@
 <body>
 	<h1>
-		CKEditor Sample
+		CKEditor Sample &mdash; Using CKEditor JavaScript API
 	</h1>
+	<div class="description">
+	<p>
+		This sample shows how to use the 
+		<a href="http://docs.cksource.com/ckeditor_api/symbols/CKEDITOR.editor.html">CKEditor JavaScript API</a>
+		to interact with the editor at runtime.
+	</p>
+	<p>
+		For details on how to create this setup check the source code of this sample page.
+	</p>
+	</div>
+
 	<!-- This <div> holds alert messages to be display in the sample page. -->
 	<div id="alerts">
@@ -129,8 +150,5 @@
 	</div>
 	<form action="sample_posteddata.php" method="post">
-		<p>
-			This sample shows how to use the CKEditor JavaScript API to interact with the editor
-			at runtime.</p>
-		<textarea cols="80" id="editor1" name="editor1" rows="10">&lt;p&gt;This is some &lt;strong&gt;sample text&lt;/strong&gt;. You are using &lt;a href="http://ckeditor.com/"&gt;CKEditor&lt;/a&gt;.&lt;/p&gt;</textarea>
+		<textarea cols="100" id="editor1" name="editor1" rows="10">&lt;p&gt;This is some &lt;strong&gt;sample text&lt;/strong&gt;. You are using &lt;a href="http://ckeditor.com/"&gt;CKEditor&lt;/a&gt;.&lt;/p&gt;</textarea>
 
 		<script type="text/javascript">
@@ -148,12 +166,12 @@
 			<input onclick="GetContents();" type="button" value="Get Editor Contents (XHTML)" />
 			<br />
-			<textarea cols="80" id="htmlArea" rows="3">&lt;h2&gt;Test&lt;/h2&gt;&lt;p&gt;This is some &lt;a href="/Test1.html"&gt;sample&lt;/a&gt; HTML&lt;/p&gt;</textarea>
+			<textarea cols="100" id="htmlArea" rows="3">&lt;h2&gt;Test&lt;/h2&gt;&lt;p&gt;This is some &lt;a href="/Test1.html"&gt;sample&lt;/a&gt; HTML code.&lt;/p&gt;</textarea>
 			<br />
 			<br />
 			<input onclick="InsertText();" type="button" value="Insert Text" />
 			<br />
-			<textarea cols="80" id="txtArea" rows="3">   First line with some leading whitespaces.
+			<textarea cols="100" id="txtArea" rows="3">   First line with some leading whitespaces.
 
-Second line of text preceding by two line-breaks.</textarea>
+Second line of text preceded by two line breaks.</textarea>
 			<br />
 			<input onclick="ExecuteCommand('bold');" type="button" value="Execute &quot;bold&quot; Command" />
@@ -168,5 +186,5 @@
 		<hr />
 		<p>
-			CKEditor - The text editor for Internet - <a href="http://ckeditor.com/">http://ckeditor.com</a>
+			CKEditor - The text editor for the Internet - <a href="http://ckeditor.com/">http://ckeditor.com</a>
 		</p>
 		<p id="copy">
Index: /CKEditor/trunk/_samples/api_dialog.html
===================================================================
--- /CKEditor/trunk/_samples/api_dialog.html	(revision 6335)
+++ /CKEditor/trunk/_samples/api_dialog.html	(revision 6336)
@@ -6,5 +6,5 @@
 <html xmlns="http://www.w3.org/1999/xhtml">
 <head>
-	<title>Using API to customize dialogs - CKEditor Sample</title>
+	<title>Using API to Customize Dialog Windows &mdash; CKEditor Sample</title>
 	<meta content="text/html; charset=utf-8" http-equiv="content-type" />
 	<!-- CKReleaser %REMOVE_LINE%
@@ -108,6 +108,29 @@
 <body>
 	<h1>
-		CKEditor Sample
+		CKEditor Sample &mdash; Using CKEditor Dialog API
 	</h1>
+	<div class="description">
+	<p>
+		This sample shows how to use the 
+		<a href="http://docs.cksource.com/ckeditor_api/symbols/CKEDITOR.dialog.html">CKEditor Dialog API</a>
+		to customize CKEditor dialog windows without changing the original editor code.
+		The following customizations are being done in the example below:
+	</p>
+	<ol>
+		<li><strong>Adding dialog window tabs</strong> &ndash; "My Tab" in the "Link" dialog window.</li>
+		<li><strong>Removing a dialog window tab</strong> &ndash; "Target" tab from the "Link" dialog window.</li>
+		<li><strong>Adding dialog window fields</strong> &ndash; "My Custom Field" in the "Link" dialog window.</li>
+		<li><strong>Removing dialog window fields</strong> &ndash; "Link Type" and "Browse Server" in the "Link"
+			dialog window.</li>
+		<li><strong>Setting default values for dialog window fields</strong> &ndash; "URL" field in the
+			"Link" dialog window. </li>
+		<li><strong>Creating a custom dialog window</strong> &ndash; "My Dialog" dialog window opened with the "My Dialog" toolbar button.</li>
+	</ol>
+	<p>
+For details on how to create this setup check the source code of this sample page.
+	</p>
+	</div>
+	
+	
 	<!-- This <div> holds alert messages to be display in the sample page. -->
 	<div id="alerts">
@@ -122,17 +145,4 @@
 	<!-- This <fieldset> holds the HTML that you will usually find in your
 	     pages. -->
-	<p>
-		This sample shows how to use the dialog API to customize dialogs whithout changing
-		the original editor code. The following customizations are being done::</p>
-	<ol>
-		<li><strong>Add dialog pages</strong> ("My Tab" in the Link dialog).</li>
-		<li><strong>Remove a dialog tab</strong> ("Target" tab from the Link dialog).</li>
-		<li><strong>Add dialog fields</strong> ("My Custom Field" into the Link dialog).</li>
-		<li><strong>Remove dialog fields</strong> ("Link Type" and "Browser Server" the Link
-			dialog).</li>
-		<li><strong>Set default values for dialog fields</strong> (for the "URL" field in the
-			Link dialog). </li>
-		<li><strong>Create a custom dialog</strong> ("My Dialog" button).</li>
-	</ol>
 	<textarea cols="80" id="editor1" name="editor1" rows="10">&lt;p&gt;This is some &lt;strong&gt;sample text&lt;/strong&gt;. You are using &lt;a href="http://ckeditor.com/"&gt;CKEditor&lt;/a&gt;.&lt;/p&gt;</textarea>
 	<script type="text/javascript">
@@ -182,5 +192,5 @@
 		<hr />
 		<p>
-			CKEditor - The text editor for Internet - <a href="http://ckeditor.com/">http://ckeditor.com</a>
+			CKEditor - The text editor for the Internet - <a href="http://ckeditor.com/">http://ckeditor.com</a>
 		</p>
 		<p id="copy">
Index: /CKEditor/trunk/_samples/asp/index.html
===================================================================
--- /CKEditor/trunk/_samples/asp/index.html	(revision 6335)
+++ /CKEditor/trunk/_samples/asp/index.html	(revision 6336)
@@ -6,10 +6,10 @@
 <html xmlns="http://www.w3.org/1999/xhtml">
 <head>
-	<title>ASP integration Samples List - CKEditor</title>
+	<title>ASP integration Samples List &mdash; CKEditor</title>
 	<link type="text/css" rel="stylesheet" href="../sample.css" />
 </head>
 <body>
 	<h1>
-		CKEditor Samples List for ASP
+		CKEditor Samples List for ASP &mdash; CKEditor Sample
 	</h1>
 	<h2>
@@ -94,5 +94,5 @@
 		<hr />
 		<p>
-			CKEditor - The text editor for Internet - <a href="http://ckeditor.com/">http://ckeditor.com</a>
+			CKEditor - The text editor for the Internet - <a href="http://ckeditor.com/">http://ckeditor.com</a>
 		</p>
 		<p id="copy">
Index: /CKEditor/trunk/_samples/assets/_posteddata.php
===================================================================
--- /CKEditor/trunk/_samples/assets/_posteddata.php	(revision 6335)
+++ /CKEditor/trunk/_samples/assets/_posteddata.php	(revision 6336)
@@ -8,5 +8,5 @@
 <html xmlns="http://www.w3.org/1999/xhtml">
 <head>
-	<title>Sample - CKEditor</title>
+	<title>Sample &mdash; CKEditor</title>
 	<meta http-equiv="content-type" content="text/html; charset=utf-8" />
 	<link type="text/css" rel="stylesheet" href="sample.css" />
@@ -14,5 +14,5 @@
 <body>
 	<h1>
-		CKEditor - Posted Data
+		CKEditor &mdash; Posted Data
 	</h1>
 	<table border="1" cellspacing="0" id="outputSample">
@@ -50,5 +50,5 @@
 		<hr />
 		<p>
-			CKEditor - The text editor for Internet - <a href="http://ckeditor.com/">http://ckeditor.com</a>
+			CKEditor - The text editor for the Internet - <a href="http://ckeditor.com/">http://ckeditor.com</a>
 		</p>
 		<p id="copy">
Index: /CKEditor/trunk/_samples/autogrow.html
===================================================================
--- /CKEditor/trunk/_samples/autogrow.html	(revision 6335)
+++ /CKEditor/trunk/_samples/autogrow.html	(revision 6336)
@@ -6,5 +6,5 @@
 <html xmlns="http://www.w3.org/1999/xhtml">
 <head>
-	<title>AutoGrow Plugin - CKEditor Sample</title>
+	<title>AutoGrow Plugin &mdash; CKEditor Sample</title>
 	<meta content="text/html; charset=utf-8" http-equiv="content-type" />
 	<!-- CKReleaser %REMOVE_LINE%
@@ -18,6 +18,36 @@
 <body>
 	<h1>
-		CKEditor Sample
+		CKEditor Sample &mdash; Using AutoGrow Plugin
 	</h1>
+	<div class="description">
+	<p>
+		This sample shows how to configure CKEditor instances to use the 
+		<strong>autogrow</strong> plugin that lets the editor window expand and shrink
+		depending on the amount and size of content entered in the editing area.
+	</p>
+	<p>
+		In its default implementation the <strong>AutoGrow feature</strong> can expand the
+		CKEditor window infinitely in order to avoid introducing scrollbars to the editing area.
+	</p>
+	<p>
+		It is also possible to set a maximum height for the editor window. Once CKEditor
+		editing area reaches the value in pixels specified in the <code>autoGrow_maxHeight</code> 
+		attribute, scrollbars will be added and the editor window will no longer expand.
+	</p>	
+	<p>
+		To add a CKEditor instance using the <strong>autogrow</strong> plugin and its
+		<code>autoGrow_maxHeight</code> attribute, insert the following JavaScript call to your code: 
+	</p>
+	<pre>CKEDITOR.replace( '<em>textarea_id</em>',
+	{
+		<strong>extraPlugins : 'autogrow',</strong>
+		autoGrow_maxHeight : 800
+	});</pre>
+	<p>
+		Note that <code><em>textarea_id</em></code> in the code above is the <code>id</code> attribute of
+		the <code>&lt;textarea&gt;</code> element to be replaced with CKEditor. The maximum height should
+		be given in pixels.
+	</p>
+	</div>
 	<!-- This <div> holds alert messages to be display in the sample page. -->
 	<div id="alerts">
@@ -32,8 +62,6 @@
 	<form action="sample_posteddata.php" method="post">
 		<p>
-			In this sample the AutoGrow plugin is available. It makes the editor grow to fit the size of the content.</p>
-		<p>
 			<label for="editor1">
-				With default configuration:</label><br />
+				CKEditor using the <strong>autogrow</strong> plugin with its default configuration:</label>
 			<textarea cols="80" id="editor1" name="editor1" rows="10">&lt;p&gt;This is some &lt;strong&gt;sample text&lt;/strong&gt;. You are using &lt;a href="http://ckeditor.com/"&gt;CKEditor&lt;/a&gt;.&lt;/p&gt;</textarea>
 			<script type="text/javascript">
@@ -49,5 +77,5 @@
 		<p>
 			<label for="editor2">
-				With maximum height set to 400:</label><br />
+				CKEditor using the <strong>autogrow</strong> plugin with maximum height set to 400:</label>
 			<textarea cols="80" id="editor2" name="editor2" rows="10">&lt;p&gt;This is some &lt;strong&gt;sample text&lt;/strong&gt;. You are using &lt;a href="http://ckeditor.com/"&gt;CKEditor&lt;/a&gt;.&lt;/p&gt;</textarea>
 			<script type="text/javascript">
@@ -69,5 +97,5 @@
 		<hr />
 		<p>
-			CKEditor - The text editor for Internet - <a href="http://ckeditor.com/">http://ckeditor.com</a>
+			CKEditor - The text editor for the Internet - <a href="http://ckeditor.com/">http://ckeditor.com</a>
 		</p>
 		<p id="copy">
Index: /CKEditor/trunk/_samples/divreplace.html
===================================================================
--- /CKEditor/trunk/_samples/divreplace.html	(revision 6335)
+++ /CKEditor/trunk/_samples/divreplace.html	(revision 6336)
@@ -6,5 +6,5 @@
 <html xmlns="http://www.w3.org/1999/xhtml">
 <head>
-	<title>Replace DIV - CKEditor Sample</title>
+	<title>Replace DIV &mdash; CKEditor Sample</title>
 	<meta content="text/html; charset=utf-8" http-equiv="content-type" />
 	<!-- CKReleaser %REMOVE_LINE%
@@ -76,6 +76,17 @@
 <body>
 	<h1>
-		CKEditor Sample
+		CKEditor Sample &mdash; Replace DIV with CKEditor on the Fly 
 	</h1>
+	<div class="description">
+	<p>
+		This sample shows how to automatically replace <code>&lt;div&gt;</code> elements
+		with a CKEditor instance on the fly, following user's doubleclick. The content
+		that was previously placed inside the <code>&lt;div&gt;</code> element will now
+		be moved into CKEditor editing area.
+	</p>
+	<p>
+		For details on how to create this setup check the source code of this sample page.
+	</p>
+	</div>
 	<!-- This <div> holds alert messages to be display in the sample page. -->
 	<div id="alerts">
@@ -89,5 +100,6 @@
 	</div>
 	<p>
-		Double-click on any of the following DIVs to transform them into editor instances.</p>
+		Double-click any of the following <code>&lt;div&gt;</code> elements to transform them into
+		editor instances.</p>
 	<div class="editable">
 		<h3>
@@ -131,5 +143,5 @@
 		<hr />
 		<p>
-			CKEditor - The text editor for Internet - <a href="http://ckeditor.com/">http://ckeditor.com</a>
+			CKEditor - The text editor for the Internet - <a href="http://ckeditor.com/">http://ckeditor.com</a>
 		</p>
 		<p id="copy">
Index: /CKEditor/trunk/_samples/enterkey.html
===================================================================
--- /CKEditor/trunk/_samples/enterkey.html	(revision 6335)
+++ /CKEditor/trunk/_samples/enterkey.html	(revision 6336)
@@ -6,5 +6,5 @@
 <html xmlns="http://www.w3.org/1999/xhtml">
 <head>
-	<title>ENTER Key Configuration - CKEditor Sample</title>
+	<title>ENTER Key Configuration &mdash; CKEditor Sample</title>
 	<meta content="text/html; charset=utf-8" http-equiv="content-type" />
 	<!-- CKReleaser %REMOVE_LINE%
@@ -41,6 +41,33 @@
 <body>
 	<h1>
-		CKEditor Sample
+		CKEditor Sample &mdash; ENTER Key Configuration
 	</h1>
+	<div class="description">
+	<p>
+		This sample shows how to configure the <em>Enter</em> and <em>Shift+Enter</em> keys 
+		to perform actions specified in the 
+		<a href="http://docs.cksource.com/ckeditor_api/symbols/CKEDITOR.config.html#.enterMode"><code>enterMode</code></a> 
+		and <a href="http://docs.cksource.com/ckeditor_api/symbols/CKEDITOR.config.html#.shiftEnterMode"><code>shiftEnterMode</code></a>
+		parameters, respectively.
+ 		You can choose from the following options:
+	</p>
+	<ul>
+		<li><strong><code>ENTER_P</code></strong> &ndash; new <code>&lt;p&gt;</code> paragraphs are created;</li>
+		<li><strong><code>ENTER_BR</code></strong> &ndash; lines are broken with <code>&lt;br&gt;</code> elements;</li>
+		<li><strong><code>ENTER_DIV</code></strong> &ndash; new <code>&lt;div&gt;</code> blocks are created.</li>
+	</ul>
+	<p>
+		The sample code below shows how to configure CKEditor to create a <code>&lt;div&gt;</code> block when <em>Enter</em> key is pressed.
+	</p>
+	<pre>CKEDITOR.replace( '<em>textarea_id</em>',
+	{
+		<strong>enterMode : CKEDITOR.ENTER_DIV</strong>
+	});</pre>
+	<p>
+		Note that <code><em>textarea_id</em></code> in the code above is the <code>id</code> attribute of
+		the <code>&lt;textarea&gt;</code> element to be replaced.
+	</p>
+	</div>
+
 	<!-- This <div> holds alert messages to be display in the sample page. -->
 	<div id="alerts">
@@ -54,16 +81,16 @@
 	</div>
 	<div style="float: left; margin-right: 20px">
-		When ENTER is pressed:<br />
+		When <em>Enter</em> is pressed:<br />
 		<select id="xEnter" onchange="changeEnter();">
-			<option selected="selected" value="1">Create new &lt;P&gt; (recommended)</option>
-			<option value="3">Create new &lt;DIV&gt;</option>
+			<option selected="selected" value="1">Create a new &lt;P&gt; (recommended)</option>
+			<option value="3">Create a new &lt;DIV&gt;</option>
 			<option value="2">Break the line with a &lt;BR&gt;</option>
 		</select>
 	</div>
 	<div style="float: left">
-		When SHIFT + ENTER is pressed:<br />
+		When <em>Shift+Enter</em> is pressed:<br />
 		<select id="xShiftEnter" onchange="changeEnter();">
-			<option value="1">Create new &lt;P&gt;</option>
-			<option value="3">Create new &lt;DIV&gt;</option>
+			<option value="1">Create a new &lt;P&gt;</option>
+			<option value="3">Create a new &lt;DIV&gt;</option>
 			<option selected="selected" value="2">Break the line with a &lt;BR&gt; (recommended)</option>
 		</select>
@@ -82,5 +109,5 @@
 		<hr />
 		<p>
-			CKEditor - The text editor for Internet - <a href="http://ckeditor.com/">http://ckeditor.com</a>
+			CKEditor - The text editor for the Internet - <a href="http://ckeditor.com/">http://ckeditor.com</a>
 		</p>
 		<p id="copy">
Index: /CKEditor/trunk/_samples/fullpage.html
===================================================================
--- /CKEditor/trunk/_samples/fullpage.html	(revision 6335)
+++ /CKEditor/trunk/_samples/fullpage.html	(revision 6336)
@@ -6,5 +6,5 @@
 <html xmlns="http://www.w3.org/1999/xhtml">
 <head>
-	<title>Full Page Editing - CKEditor Sample</title>
+	<title>Full Page Editing &mdash; CKEditor Sample</title>
 	<meta content="text/html; charset=utf-8" http-equiv="content-type" />
 	<!-- CKReleaser %REMOVE_LINE%
@@ -18,6 +18,24 @@
 <body>
 	<h1>
-		CKEditor Sample
+		CKEditor Sample &mdash; Full Page Editing
 	</h1>
+	<div class="description">
+	<p>
+		This sample shows how to configure CKEditor to edit entire HTML pages, from the
+		<code>&lt;html&gt;</code> tag to the <code>&lt;/html&gt;</code> tag.
+	</p>
+	<p>	
+		CKEditor is inserted with a JavaScript call using the following code: 
+	</p>
+	<pre>CKEDITOR.replace( '<em>textarea_id</em>',
+	{
+		<strong>fullPage : true</strong>
+	});</pre>
+	<p>
+		Note that <code><em>textarea_id</em></code> in the code above is the <code>id</code> attribute of
+		the <code>&lt;textarea&gt;</code> element to be replaced.
+	</p>
+	</div>
+	
 	<!-- This <div> holds alert messages to be display in the sample page. -->
 	<div id="alerts">
@@ -31,10 +49,6 @@
 	</div>
 	<form action="sample_posteddata.php" method="post">
-		<p>
-			In this sample the editor is configured to edit entire HTML pages, from the &lt;html&gt;
-			tag to &lt;/html&gt;.</p>
-		<p>
 			<label for="editor1">
-				Editor 1:</label><br />
+				Editor 1:</label>
 			<textarea cols="80" id="editor1" name="editor1" rows="10">&lt;html&gt;&lt;head&gt;&lt;title&gt;CKEditor Sample&lt;/title&gt;&lt;/head&gt;&lt;body&gt;&lt;p&gt;This is some &lt;strong&gt;sample text&lt;/strong&gt;. You are using &lt;a href="http://ckeditor.com/"&gt;CKEditor&lt;/a&gt;.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</textarea>
 			<script type="text/javascript">
@@ -48,5 +62,4 @@
 			//]]>
 			</script>
-		</p>
 		<p>
 			<input type="submit" value="Submit" />
@@ -56,5 +69,5 @@
 		<hr />
 		<p>
-			CKEditor - The text editor for Internet - <a href="http://ckeditor.com/">http://ckeditor.com</a>
+			CKEditor - The text editor for the Internet - <a href="http://ckeditor.com/">http://ckeditor.com</a>
 		</p>
 		<p id="copy">
Index: /CKEditor/trunk/_samples/index.html
===================================================================
--- /CKEditor/trunk/_samples/index.html	(revision 6335)
+++ /CKEditor/trunk/_samples/index.html	(revision 6336)
@@ -6,10 +6,11 @@
 <html xmlns="http://www.w3.org/1999/xhtml">
 <head>
-	<title>Samples List - CKEditor</title>
+	<title>CKEditor Samples</title>
+	<meta content="text/html; charset=utf-8" http-equiv="content-type" />
 	<link type="text/css" rel="stylesheet" href="sample.css" />
 </head>
 <body>
 	<h1>
-		CKEditor Samples List
+		CKEditor Samples Site
 	</h1>
 	<h2>
@@ -17,7 +18,14 @@
 	</h2>
 	<ul>
-		<li><a href="replacebyclass.html">Replace textareas by class name</a></li>
-		<li><a href="replacebycode.html">Replace textareas by code</a></li>
-		<li><a href="fullpage.html">Full page support (editing from &lt;html&gt; to &lt;/html&gt;)</a></li>
+		<li>
+			<a href="replacebyclass.html">Replace textarea elements by class name</a><br />
+			Automatic replacement of all textarea elements of a given class with a CKEditor instance.
+		</li>
+		<li><a href="replacebycode.html">Replace textarea elements by code</a><br />
+			Replacement of textarea elements with CKEditor instances by using a JavaScript call.
+		</li>
+		<li><a href="fullpage.html">Full page support</a><br />
+			CKEditor inserted with a JavaScript call and used to edit the whole page from <code>&lt;html&gt;</code> to <code>&lt;/html&gt;</code>.
+		</li>
 	</ul>
 	<h2>
@@ -25,7 +33,16 @@
 	</h2>
 	<ul>
-		<li><a href="skins.html">Skins</a></li>
-		<li><a href="ui_color.html">User Interface Color</a></li>
-		<li><a href="ui_languages.html">User Interface Languages</a></li>
+		<li><a href="skins.html">Skins</a><br />
+			Changing the CKEditor skin by adjusting a single configuration option.
+		</li>
+		<li><a href="ui_color.html">User Interface color</a><br />
+			Changing CKEditor User Interface color and adding a toolbar button that lets the user set the UI color.
+		</li>
+		<li><a href="ui_languages.html">User Interface languages</a><br />
+			Changing CKEditor User Interface language and adding a drop-down list that lets the user choose the UI language.
+		</li>
+		<li><a href="autogrow.html">AutoGrow plugin</a><br />
+			Using the AutoGrow plugin in order to make the editor grow to fit the size of its content.
+		</li>
 	</ul>
 	<h2>
@@ -33,21 +50,42 @@
 	</h2>
 	<ul>
-		<li><a href="divreplace.html">Replace DIV elements on the fly</a>&nbsp; </li>
-		<li><a href="ajax.html">Create and destroy editor instances for Ajax applications</a></li>
-		<li><a href="api.html">Basic usage of the API</a></li>
-		<li><a href="api_dialog.html">Using the JavaScript API to customize dialogs</a></li>
-		<li><a href="enterkey.html">Using the "Enter" key in CKEditor</a></li>
-		<li><a href="sharedspaces.html">Shared toolbars</a></li>
-		<li><a href="jqueryadapter.html">jQuery adapter example</a></li>
-		<li><a href="output_xhtml.html">Output XHTML</a></li>
-		<li><a href="output_html.html">Output HTML</a></li>
-		<li><a href="output_for_flash.html">Output for Flash</a></li>
-		<li><a href="autogrow.html">AutoGrow plugin</a></li>
-		<li><a href="placeholder.html">Placeholder plugin</a></li>
+		<li><a href="divreplace.html">Replace DIV elements on the fly</a><br />
+			Transforming a <code>div</code> element into an instance of CKEditor with a mouse click.	
+		</li>
+		<li><a href="ajax.html">Create and destroy editor instances for Ajax applications</a><br />
+			Creating and destroying CKEditor instances on the fly and saving the contents entered into the editor window. 
+		</li>
+		<li><a href="api.html">Basic usage of the API</a><br />
+			Using the CKEditor JavaScript API to interact with the editor at runtime.
+		</li>
+		<li><a href="api_dialog.html">Using the JavaScript API to customize dialog windows</a><br />
+			Using the dialog windows API to customize dialog windows without changing the original editor code.
+		</li>
+		<li><a href="enterkey.html">Using the "Enter" key in CKEditor</a><br />
+			 Configuring the behavior of <em>Enter</em> and <em>Shift+Enter</em> keys. 
+		</li>
+		<li><a href="sharedspaces.html">Shared toolbars</a><br />
+			Displaying multiple editor instances that share the toolbar and/or the elements path.
+		</li>
+		<li><a href="jqueryadapter.html">jQuery adapter example</a><br />
+			Using the jQuery adapter to configure CKEditor.
+		</li>
+		<li><a href="output_xhtml.html">Output XHTML</a><br />
+			Configuring CKEditor to produce XHTML 1.1 compliant code.
+		</li>
+		<li><a href="output_html.html">Output HTML</a><br />
+			Configuring CKEditor to produce legacy HTML 4 code.
+		</li>
+		<li><a href="output_for_flash.html">Output for Flash</a><br />
+			Configuring CKEditor to produce HTML code that can be used with Adobe Flash. 
+		</li>
+		<li><a href="placeholder.html">Placeholder plugin</a><br />
+			Using the Placeholder plugin to create uneditable sections that can only be created and modified with a proper dialog window.
+		</li>
 	</ul>
 	<div id="footer">
 		<hr />
 		<p>
-			CKEditor - The text editor for Internet - <a href="http://ckeditor.com/">http://ckeditor.com</a>
+			CKEditor - The text editor for the Internet - <a href="http://ckeditor.com/">http://ckeditor.com</a>
 		</p>
 		<p id="copy">
Index: /CKEditor/trunk/_samples/jqueryadapter.html
===================================================================
--- /CKEditor/trunk/_samples/jqueryadapter.html	(revision 6335)
+++ /CKEditor/trunk/_samples/jqueryadapter.html	(revision 6336)
@@ -6,5 +6,5 @@
 <html xmlns="http://www.w3.org/1999/xhtml">
 <head>
-	<title>jQuery adapter - CKEditor Sample</title>
+	<title>jQuery Adapter &mdash; CKEditor Sample</title>
 	<meta content="text/html; charset=utf-8" http-equiv="content-type" />
 	<script type="text/javascript" src="https://ajax.googleapis.com/ajax/libs/jquery/1/jquery.js"></script>
@@ -41,6 +41,32 @@
 <body>
 	<h1>
-		CKEditor Sample
+		CKEditor Sample &mdash; Using jQuery Adapter
 	</h1>
+	<div class="description">
+	<p>
+		This sample shows how to load CKEditor and configure it using the 
+		<a href="http://docs.cksource.com/CKEditor_3.x/Developers_Guide/jQuery_Adapter">jQuery adapter</a>.
+		In this case the jQuery adapter is responsible for transforming a <code>&lt;textarea&gt;</code>
+		element into a CKEditor instance and setting the configuration of the toolbar.
+	</p>
+	<p>
+		CKEditor instance with custom configuration set in jQuery can be inserted with the   
+		following JavaScript code: 
+	</p>
+	<pre>$(function()
+{
+	var config = {
+		skin:'v2'
+	};
+
+	$('.<em>textarea_class</em>').ckeditor(config);
+});</pre>
+	<p>
+	Note that <code><em>textarea_class</em></code> in the code above is the
+	<code>class</code> attribute of the <code>&lt;textarea&gt;</code> element to be replaced with
+	CKEditor. Any other jQuery selector can be used to match the target element.
+	</p>
+	</div>
+		
 	<!-- This <div> holds alert messages to be display in the sample page. -->
 	<div id="alerts">
@@ -58,5 +84,5 @@
 	<p>
 		<label for="editor1">
-			Editor 1:</label><br />
+			Editor 1:</label>
 		<textarea class="jquery_ckeditor" cols="80" id="editor1" name="editor1" rows="10">&lt;p&gt;This is some &lt;strong&gt;sample text&lt;/strong&gt;. You are using &lt;a href="http://ckeditor.com/"&gt;CKEditor&lt;/a&gt;.&lt;/p&gt;</textarea>
 	</p>
@@ -68,5 +94,5 @@
 		<hr />
 		<p>
-			CKEditor - The text editor for Internet - <a href="http://ckeditor.com/">http://ckeditor.com</a>
+			CKEditor - The text editor for the Internet - <a href="http://ckeditor.com/">http://ckeditor.com</a>
 		</p>
 		<p id="copy">
Index: /CKEditor/trunk/_samples/output_for_flash.html
===================================================================
--- /CKEditor/trunk/_samples/output_for_flash.html	(revision 6335)
+++ /CKEditor/trunk/_samples/output_for_flash.html	(revision 6336)
@@ -6,5 +6,5 @@
 <html xmlns="http://www.w3.org/1999/xhtml">
 <head>
-	<title>Output for Flash</title>
+	<title>Output for Flash &mdash; CKEditor Sample</title>
 	<meta content="text/html; charset=utf-8" http-equiv="content-type" />
 	<!-- CKReleaser %REMOVE_LINE%
@@ -34,6 +34,29 @@
 <body onload="init()">
 	<h1>
-		CKEditor Sample
+		CKEditor Sample &mdash; Producing Flash Compliant HTML Output
 	</h1>
+	<div class="description">
+	<p>
+		This sample shows how to configure CKEditor to output 
+		HTML code that can be used with
+		<a href="http://www.adobe.com/livedocs/flash/9.0/main/wwhelp/wwhimpl/common/html/wwhelp.htm?context=LiveDocs_Parts&amp;file=00000922.html">
+		Adobe Flash</a>.
+		The code will contain a subset of standard HTML elements like <code>&lt;b&gt;</code>,
+		<code>&lt;i&gt;</code>, and <code>&lt;p&gt;</code> as well as HTML attributes.
+	</p>
+	<p>
+		To add a CKEditor instance outputting Flash compliant HTML code, load the editor using a standard
+		JavaScript call, and define CKEditor features to use HTML elements and attributes.
+	</p>
+	<p>
+		For details on how to create this setup check the source code of this sample page.
+	</p>
+	</div>
+	<p>
+		To see how it works, create some content in the editing area of CKEditor on the left
+		and send it to the Flash object on the right side of the page by using the
+		<strong>Send to Flash</strong> button.
+	</p>
+
 	<!-- This <div> holds alert messages to be display in the sample page. -->
 	<div id="alerts">
@@ -45,10 +68,4 @@
 			</p>
 		</noscript>
-	</div>
-
-	<div>
-		This sample shows CKEditor configured to produce HTML code that can be used with
-		<a href="http://www.adobe.com/livedocs/flash/9.0/main/wwhelp/wwhimpl/common/html/wwhelp.htm?context=LiveDocs_Parts&amp;file=00000922.html">
-			Flash</a>.
 	</div>
 	<hr />
@@ -251,5 +268,5 @@
 		<hr />
 		<p>
-			CKEditor - The text editor for Internet - <a href="http://ckeditor.com/">http://ckeditor.com</a>
+			CKEditor - The text editor for the Internet - <a href="http://ckeditor.com/">http://ckeditor.com</a>
 		</p>
 		<p id="copy">
Index: /CKEditor/trunk/_samples/output_html.html
===================================================================
--- /CKEditor/trunk/_samples/output_html.html	(revision 6335)
+++ /CKEditor/trunk/_samples/output_html.html	(revision 6336)
@@ -6,5 +6,5 @@
 <html xmlns="http://www.w3.org/1999/xhtml">
 <head>
-	<title>HTML compliant output - CKEditor Sample</title>
+	<title>HTML Compliant Output &mdash; CKEditor Sample</title>
 	<meta content="text/html; charset=utf-8" http-equiv="content-type" />
 	<!-- CKReleaser %REMOVE_LINE%
@@ -18,6 +18,37 @@
 <body>
 	<h1>
-		CKEditor Sample
+		CKEditor Sample &mdash; Producing HTML Compliant Output
 	</h1>
+	<div class="description">
+	<p>
+		This sample shows how to configure CKEditor to output valid
+		<a href="http://www.w3.org/TR/html401/">HTML 4.01</a> code.
+		Traditional HTML elements like <code>&lt;b&gt;</code>,
+		<code>&lt;i&gt;</code>, and <code>&lt;font&gt;</code> are used in place of
+		<code>&lt;strong&gt;</code>, <code>&lt;em&gt;</code>, and CSS styles.
+	</p>
+	<p>
+		To add a CKEditor instance outputting legacy HTML 4.01 code, load the editor using a standard
+		JavaScript call, and define CKEditor features to use the HTML compliant elements and attributes.
+	</p>
+	<p>
+		A snippet of the configuration code can be seen below; check the source of this page for 
+		full definition:
+	</p>
+	<pre>CKEDITOR.replace( '<em>textarea_id</em>',
+	{
+		coreStyles_bold	: { element : 'b' },
+		coreStyles_italic : { element : 'i' },
+
+		fontSize_style :
+			{
+				element		: 'font',
+				attributes	: { 'size' : '#(size)' }
+			}
+			
+		// More definitions follow.
+	});</pre>
+	</div>
+
 	<!-- This <div> holds alert messages to be display in the sample page. -->
 	<div id="alerts">
@@ -32,10 +63,6 @@
 	<form action="sample_posteddata.php" method="post">
 		<p>
-			This sample shows CKEditor configured to produce a legacy <strong>HTML4</strong> document. Traditional
-			HTML elements like &lt;b&gt;, &lt;i&gt;, and &lt;font&gt; are used in place of
-			&lt;strong&gt;, &lt;em&gt; and CSS styles.</p>
-		<p>
 			<label for="editor1">
-				Editor 1:</label><br />
+				Editor 1:</label>
 			<textarea cols="80" id="editor1" name="editor1" rows="10">&lt;p&gt;This is some &lt;b&gt;sample text&lt;/b&gt;. You are using &lt;a href="http://ckeditor.com/"&gt;CKEditor&lt;/a&gt;.&lt;/p&gt;</textarea>
 			<script type="text/javascript">
@@ -253,5 +280,5 @@
 		<hr />
 		<p>
-			CKEditor - The text editor for Internet - <a href="http://ckeditor.com/">http://ckeditor.com</a>
+			CKEditor - The text editor for the Internet - <a href="http://ckeditor.com/">http://ckeditor.com</a>
 		</p>
 		<p id="copy">
Index: /CKEditor/trunk/_samples/output_xhtml.html
===================================================================
--- /CKEditor/trunk/_samples/output_xhtml.html	(revision 6335)
+++ /CKEditor/trunk/_samples/output_xhtml.html	(revision 6336)
@@ -6,5 +6,5 @@
 <html xmlns="http://www.w3.org/1999/xhtml">
 <head>
-	<title>XHTML compliant output - CKEditor Sample</title>
+	<title>XHTML Compliant Output &mdash; CKEditor Sample</title>
 	<meta content="text/html; charset=utf-8" http-equiv="content-type" />
 	<!-- CKReleaser %REMOVE_LINE%
@@ -18,6 +18,32 @@
 <body>
 	<h1>
-		CKEditor Sample
+		CKEditor Sample &mdash; Producing XHTML Compliant Output
 	</h1>
+	<div class="description">
+	<p>
+		This sample shows how to configure CKEditor to output valid
+		<a href="http://www.w3.org/TR/xhtml11/">XHTML 1.1</a> code.
+		Deprecated elements (<code>&lt;font&gt;</code>, <code>&lt;u&gt;</code>) or attributes
+		(<code>size</code>, <code>face</code>) will be replaced with XHTML compliant code.
+	</p>
+	<p>
+		To add a CKEditor instance outputting valid XHTML code, load the editor using a standard
+		JavaScript call and define CKEditor features to use the XHTML compliant elements and styles.
+	</p>
+	<p>
+		A snippet of the configuration code can be seen below; check the source of this page for 
+		full definition:
+	</p>
+	<pre>CKEDITOR.replace( '<em>textarea_id</em>',
+	{
+		contentsCss : 'assets/output_xhtml.css',
+
+		coreStyles_bold	: { element : 'span', attributes : {'class': 'Bold'} },
+		coreStyles_italic : { element : 'span', attributes : {'class': 'Italic'} },
+
+		// More definitions follow.
+	});</pre>
+	</div>
+
 	<!-- This <div> holds alert messages to be display in the sample page. -->
 	<div id="alerts">
@@ -32,10 +58,6 @@
 	<form action="sample_posteddata.php" method="post">
 		<p>
-			This sample shows CKEditor configured to produce <strong>XHTML 1.1</strong> compliant
-			HTML. Deprecated elements or attributes, like the &lt;font&gt; and &lt;u&gt; elements
-			or the "style" attribute, are avoided.</p>
-		<p>
 			<label for="editor1">
-				Editor 1:</label><br />
+				Editor 1:</label>
 			<textarea cols="80" id="editor1" name="editor1" rows="10">&lt;p&gt;This is some &lt;span class="Bold"&gt;sample text&lt;/span&gt;. You are using &lt;a href="http://ckeditor.com/"&gt;CKEditor&lt;/a&gt;.&lt;/p&gt;</textarea>
 			<script type="text/javascript">
@@ -153,5 +175,5 @@
 		<hr />
 		<p>
-			CKEditor - The text editor for Internet - <a href="http://ckeditor.com/">http://ckeditor.com</a>
+			CKEditor - The text editor for the Internet - <a href="http://ckeditor.com/">http://ckeditor.com</a>
 		</p>
 		<p id="copy">
Index: /CKEditor/trunk/_samples/php/advanced.php
===================================================================
--- /CKEditor/trunk/_samples/php/advanced.php	(revision 6335)
+++ /CKEditor/trunk/_samples/php/advanced.php	(revision 6336)
@@ -6,5 +6,5 @@
 <html xmlns="http://www.w3.org/1999/xhtml">
 <head>
-	<title>Sample - CKEditor</title>
+	<title>Setting Configuration Options &mdash; CKEditor Sample</title>
 	<meta content="text/html; charset=utf-8" http-equiv="content-type"/>
 	<link href="../sample.css" rel="stylesheet" type="text/css"/>
@@ -12,6 +12,40 @@
 <body>
 	<h1>
-		CKEditor Sample
+		CKEditor Sample &mdash; Setting Configuration Options
 	</h1>
+	<p>
+		This sample shows how to insert a CKEditor instance with custom configuration options.
+	</p>
+	<p>
+		To set configuration options, use the <a href="http://docs.cksource.com/ckeditor_api/symbols/CKEDITOR.config.html"><code>config</code></a> property. To set the attributes of a <code>&lt;textarea&gt;</code> element (which is displayed instead of CKEditor in unsupported browsers), use the <code>textareaAttributes</code> property.
+	</p>
+	<pre>
+&lt;?php
+// Include the CKEditor class.
+include_once "ckeditor/ckeditor.php";
+
+// Create a class instance.
+$CKEditor = new CKEditor();
+
+// Path to the CKEditor directory.
+$CKEditor->basePath = '/ckeditor/';
+
+// Set global configuration (used by every instance of CKEditor).
+$CKEditor-><strong>config['width']</strong> = 600;
+
+// Change default textarea attributes.
+$CKEditor-><strong>textareaAttributes</strong> = array("cols" => 80, "rows" => 10);
+
+// The initial value to be displayed in the editor.
+$initialValue = 'This is some sample text.';
+
+// Create the first instance.
+$CKEditor->editor("textarea_id", $initialValue);
+?&gt;</pre>
+	<p>
+		Note that <code><em>textarea_id</em></code> in the code above is the <code>name</code> attribute of
+		the <code>&lt;textarea&gt;</code> element to be created.
+	</p>
+
 	<!-- This <div> holds alert messages to be display in the sample page. -->
 	<div id="alerts">
@@ -24,22 +58,17 @@
 		</noscript>
 	</div>
-	<!-- This <fieldset> holds the HTML that you will usually find in your pages. -->
-	<fieldset title="Output">
-		<legend>Output</legend>
-		<form action="../sample_posteddata.php" method="post">
-			<p>
-				<label>Editor 1:</label><br/>
-			</p>
+	<form action="../sample_posteddata.php" method="post">
+			<label>Editor 1:</label>
 <?php
-// Include CKEditor class.
+// Include the CKEditor class.
 include("../../ckeditor.php");
 
-// Create class instance.
+// Create a class instance.
 $CKEditor = new CKEditor();
 
-// Do not print the code directly to the browser, return it instead
+// Do not print the code directly to the browser, return it instead.
 $CKEditor->returnOutput = true;
 
-// Path to CKEditor directory, ideally instead of relative dir, use an absolute path:
+// Path to the CKEditor directory, ideally use an absolute path instead of a relative dir.
 //   $CKEditor->basePath = '/ckeditor/'
 // If not set, CKEditor will try to detect the correct path.
@@ -49,5 +78,5 @@
 $CKEditor->config['width'] = 600;
 
-// Change default textarea attributes
+// Change default textarea attributes.
 $CKEditor->textareaAttributes = array("cols" => 80, "rows" => 10);
 
@@ -55,14 +84,13 @@
 $initialValue = '<p>This is some <strong>sample text</strong>. You are using <a href="http://ckeditor.com/">CKEditor</a>.</p>';
 
-// Create first instance.
+// Create the first instance.
 $code = $CKEditor->editor("editor1", $initialValue);
 
 echo $code;
 ?>
-			<p>
-				<label>Editor 2:</label><br/>
-			</p>
+				<br />
+				<label>Editor 2:</label>
 <?php
-// Configuration that will be used only by the second editor.
+// Configuration that will only be used by the second editor.
 $config['toolbar'] = array(
 	array( 'Source', '-', 'Bold', 'Italic', 'Underline', 'Strike' ),
@@ -72,16 +100,15 @@
 $config['skin'] = 'v2';
 
-// Create second instance.
+// Create the second instance.
 echo $CKEditor->editor("editor2", $initialValue, $config);
 ?>
-			<p>
-				<input type="submit" value="Submit"/>
-			</p>
-		</form>
-	</fieldset>
+		<p>
+			<input type="submit" value="Submit"/>
+		</p>
+	</form>
 	<div id="footer">
 		<hr />
 		<p>
-			CKEditor - The text editor for Internet - <a href="http://ckeditor.com/">http://ckeditor.com</a>
+			CKEditor - The text editor for the Internet - <a href="http://ckeditor.com/">http://ckeditor.com</a>
 		</p>
 		<p id="copy">
Index: /CKEditor/trunk/_samples/php/index.html
===================================================================
--- /CKEditor/trunk/_samples/php/index.html	(revision 6336)
+++ /CKEditor/trunk/_samples/php/index.html	(revision 6336)
@@ -0,0 +1,47 @@
+<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
+<!--
+Copyright (c) 2003-2010, CKSource - Frederico Knabben. All rights reserved.
+For licensing, see LICENSE.html or http://ckeditor.com/license
+-->
+<html xmlns="http://www.w3.org/1999/xhtml">
+<head>
+  <meta content="text/html; charset=utf-8" http-equiv="content-type" />
+	<title>CKEditor Samples &mdash; PHP Integration</title>
+	<link type="text/css" rel="stylesheet" href="../sample.css" />
+</head>
+<body>
+	<h1>
+		CKEditor Samples List for PHP
+	</h1>
+	<h2>
+		Basic Samples
+	</h2>
+	<ul>
+		<li><a href="replace.php">Replace existing textarea elements by code</a><br />
+		Replacement of selected textarea elements with CKEditor instances by using a JavaScript call.</li>
+		<li><a href="replaceAll.php">Replace all textarea elements by code</a><br />
+		Replacement of all textarea elements with CKEditor instances by using a JavaScript call.</li>
+		<li><a href="standalone.php">Create CKEditor instances in PHP</a><br />
+		Creating a CKEditor instance (no initial textarea element is required).</li>
+	</ul>
+	<h2>
+		Advanced Samples
+	</h2>
+	<ul>
+		<li><a href="advanced.php">Setting configuration options</a><br />
+		Creating a CKEditor instance with custom configuration options.</li>
+		<li><a href="events.php">Listening to events</a><br />
+		Creating event handlers.
+		</li>
+	</ul>
+	<div id="footer">
+		<hr />
+		<p>
+			CKEditor - The text editor for the Internet - <a href="http://ckeditor.com/">http://ckeditor.com</a>
+		</p>
+		<p id="copy">
+			Copyright &copy; 2003-2010, <a href="http://cksource.com/">CKSource</a> - Frederico Knabben. All rights reserved.
+		</p>
+	</div>
+</body>
+</html>
Index: /CKEditor/trunk/_samples/php/standalone.php
===================================================================
--- /CKEditor/trunk/_samples/php/standalone.php	(revision 6335)
+++ /CKEditor/trunk/_samples/php/standalone.php	(revision 6336)
@@ -6,5 +6,5 @@
 <html xmlns="http://www.w3.org/1999/xhtml">
 <head>
-	<title>Sample - CKEditor</title>
+	<title>Creating CKEditor Instances &mdash; CKEditor Sample</title>
 	<meta content="text/html; charset=utf-8" http-equiv="content-type"/>
 	<link href="../sample.css" rel="stylesheet" type="text/css"/>
@@ -12,6 +12,28 @@
 <body>
 	<h1>
-		CKEditor Sample
+		CKEditor Sample &mdash; Creating CKEditor Instances
 	</h1>
+	<div class="description">
+	<p>
+		This sample shows how to create a CKEditor instance with PHP.
+	</p>
+	<pre>
+&lt;?php 
+include_once "ckeditor/ckeditor.php";
+
+// Create a class instance.
+$CKEditor = new CKEditor();
+
+// Path to the CKEditor directory.
+$CKEditor->basePath = '/ckeditor/';
+
+// Create a textarea element and attach CKEditor to it.
+$CKEditor->editor("textarea_id", "This is some sample text");
+?&gt;</pre>
+	<p>
+		Note that <code><em>textarea_id</em></code> in the code above is the <code>id</code> and <code>name</code> attribute of
+		the <code>&lt;textarea&gt;</code> element that will be created.
+	</p>
+	</div>
 	<!-- This <div> holds alert messages to be display in the sample page. -->
 	<div id="alerts">
@@ -24,35 +46,32 @@
 		</noscript>
 	</div>
-	<!-- This <fieldset> holds the HTML that you will usually find in your pages. -->
-	<fieldset title="Output">
-		<legend>Output</legend>
-		<form action="../sample_posteddata.php" method="post">
-			<p>
-				<label for="editor1">
-					Editor 1:</label><br/>
-			</p>
-			<p>
-			<?php
-				// Include CKEditor class.
-				include_once "../../ckeditor.php";
-				// The initial value to be displayed in the editor.
-				$initialValue = '<p>This is some <strong>sample text</strong>.</p>';
-				// Create class instance.
-				$CKEditor = new CKEditor();
-				// Path to CKEditor directory, ideally instead of relative dir, use an absolute path:
-				//   $CKEditor->basePath = '/ckeditor/'
-				// If not set, CKEditor will try to detect the correct path.
-				$CKEditor->basePath = '../../';
-				// Create textarea element and attach CKEditor to it.
-				$CKEditor->editor("editor1", $initialValue);
-			?>
-				<input type="submit" value="Submit"/>
-			</p>
-		</form>
-	</fieldset>
+	<!-- This <fieldset> holds the HTML code that you will usually find in your pages. -->
+	<form action="../sample_posteddata.php" method="post">
+		<p>
+			<label for="editor1">
+				Editor 1:</label>
+		</p>
+		<p>
+		<?php
+			// Include the CKEditor class.
+			include_once "../../ckeditor.php";
+			// The initial value to be displayed in the editor.
+			$initialValue = '<p>This is some <strong>sample text</strong>.</p>';
+			// Create a class instance.
+			$CKEditor = new CKEditor();
+			// Path to the CKEditor directory, ideally use an absolute path instead of a relative dir.
+			//   $CKEditor->basePath = '/ckeditor/'
+			// If not set, CKEditor will try to detect the correct path.
+			$CKEditor->basePath = '../../';
+			// Create a textarea element and attach CKEditor to it.
+			$CKEditor->editor("editor1", $initialValue);
+		?>
+			<input type="submit" value="Submit"/>
+		</p>
+	</form>
 	<div id="footer">
 		<hr />
 		<p>
-			CKEditor - The text editor for Internet - <a href="http://ckeditor.com/">http://ckeditor.com</a>
+			CKEditor - The text editor for the Internet - <a href="http://ckeditor.com/">http://ckeditor.com</a>
 		</p>
 		<p id="copy">
Index: /CKEditor/trunk/_samples/placeholder.html
===================================================================
--- /CKEditor/trunk/_samples/placeholder.html	(revision 6335)
+++ /CKEditor/trunk/_samples/placeholder.html	(revision 6336)
@@ -6,5 +6,5 @@
 <html xmlns="http://www.w3.org/1999/xhtml">
 <head>
-	<title>Placeholder Plugin - CKEditor Sample</title>
+	<title>Placeholder Plugin &mdash; CKEditor Sample</title>
 	<meta content="text/html; charset=utf-8" http-equiv="content-type" />
 	<!-- CKReleaser %REMOVE_LINE%
@@ -18,6 +18,28 @@
 <body>
 	<h1>
-		CKEditor Sample
+		CKEditor Sample &mdash; Using the Placeholder Plugin
 	</h1>
+	<div class="description">
+	<p>
+		This sample shows how to configure CKEditor instances to use the 
+		<strong>placeholder</strong> plugin that lets you insert read-only elements
+		into your content. To enter and modify read-only text, use the
+		<strong>Create Placeholder</strong> button and its matching dialog window.
+	</p>
+	<p>
+		To add a CKEditor instance that uses the <strong>placeholder</strong> plugin and a related
+		<strong>Create Placeholder</strong> toolbar button, insert the following JavaScript
+		call to your code: 
+	</p>
+	<pre>CKEDITOR.replace( '<em>textarea_id</em>',
+	{
+		<strong>extraPlugins : 'placeholder',</strong>
+		toolbar : [ [ 'Source', 'Bold' ], [<strong>'CreatePlaceholder'</strong>] ]
+	});</pre>
+	<p>
+		Note that <code><em>textarea_id</em></code> in the code above is the <code>id</code> attribute of
+		the <code>&lt;textarea&gt;</code> element to be replaced with CKEditor.
+	</p>
+	</div>
 	<!-- This <div> holds alert messages to be display in the sample page. -->
 	<div id="alerts">
@@ -32,9 +54,6 @@
 	<form action="sample_posteddata.php" method="post">
 		<p>
-			In this sample the Placeholder plugin is available.<br />
-			It replaces text in the format of <code>[[text]]</code> to uneditable sections, and lets the user edit them and create new ones using a dialog.</p>
-		<p>
 			<label for="editor1">
-				With default configuration:</label><br />
+				CKEditor using the <strong>placeholder</strong> plugin with its default configuration:</label>
 			<textarea cols="80" id="editor1" name="editor1" rows="10">&lt;p&gt;This is a [[sample placeholder]]. You are using &lt;a href="http://ckeditor.com/"&gt;CKEditor&lt;/a&gt;. &lt;/p&gt;</textarea>
 			<script type="text/javascript">
@@ -56,5 +75,5 @@
 		<hr />
 		<p>
-			CKEditor - The text editor for Internet - <a href="http://ckeditor.com/">http://ckeditor.com</a>
+			CKEditor - The text editor for the Internet - <a href="http://ckeditor.com/">http://ckeditor.com</a>
 		</p>
 		<p id="copy">
Index: /CKEditor/trunk/_samples/replacebyclass.html
===================================================================
--- /CKEditor/trunk/_samples/replacebyclass.html	(revision 6335)
+++ /CKEditor/trunk/_samples/replacebyclass.html	(revision 6336)
@@ -6,5 +6,5 @@
 <html xmlns="http://www.w3.org/1999/xhtml">
 <head>
-	<title>Replace Textareas by Class Name - CKEditor Sample</title>
+	<title>Replace Textareas by Class Name &mdash; CKEditor Sample</title>
 	<meta content="text/html; charset=utf-8" http-equiv="content-type" />
 	<!-- CKReleaser %REMOVE_LINE%
@@ -18,6 +18,21 @@
 <body>
 	<h1>
-		CKEditor Sample
+		CKEditor Sample &mdash; Replace Textarea Elements by Class Name
 	</h1>
+	<div class="description">
+	<p>
+		This sample shows how to automatically replace all <code>&lt;textarea&gt;</code> elements
+		of a given class with a CKEditor instance.
+	</p>
+	<p>
+		To replace a <code>&lt;textarea&gt;</code> element, simply assign it the <code>ckeditor</code>
+		class, as in the code below: 
+	</p>
+	<pre>&lt;textarea <strong>class="ckeditor</strong>" name="editor1"&gt;&lt;/textarea&gt;</pre>
+	<p>
+		Note that other <code>&lt;textarea&gt;</code> attributes (like <code>id</code> or <code>name</code>) need to be adjusted to your document.
+	</p>
+	</div>
+	
 	<!-- This <div> holds alert messages to be display in the sample page. -->
 	<div id="alerts">
@@ -33,5 +48,5 @@
 		<p>
 			<label for="editor1">
-				Editor 1:</label><br />
+				Editor 1:</label>
 			<textarea class="ckeditor" cols="80" id="editor1" name="editor1" rows="10">&lt;p&gt;This is some &lt;strong&gt;sample text&lt;/strong&gt;. You are using &lt;a href="http://ckeditor.com/"&gt;CKEditor&lt;/a&gt;.&lt;/p&gt;</textarea>
 		</p>
@@ -43,5 +58,5 @@
 		<hr />
 		<p>
-			CKEditor - The text editor for Internet - <a href="http://ckeditor.com/">http://ckeditor.com</a>
+			CKEditor - The text editor for the Internet - <a href="http://ckeditor.com/">http://ckeditor.com</a>
 		</p>
 		<p id="copy">
Index: /CKEditor/trunk/_samples/replacebycode.html
===================================================================
--- /CKEditor/trunk/_samples/replacebycode.html	(revision 6335)
+++ /CKEditor/trunk/_samples/replacebycode.html	(revision 6336)
@@ -6,5 +6,5 @@
 <html xmlns="http://www.w3.org/1999/xhtml">
 <head>
-	<title>Replace Textarea by Code - CKEditor Sample</title>
+	<title>Replace Textarea by Code &mdash; CKEditor Sample</title>
 	<meta content="text/html; charset=utf-8" http-equiv="content-type" />
 	<!-- CKReleaser %REMOVE_LINE%
@@ -18,6 +18,23 @@
 <body>
 	<h1>
-		CKEditor Sample
+		CKEditor Sample &mdash; Replace Textarea Elements Using JavaScript Code 
 	</h1>
+	<div class="description">
+	<p>
+		This sample shows how to automatically replace all <code>&lt;textarea&gt;</code> elements
+		with a CKEditor instance by using a JavaScript call.
+	</p>
+	<p>
+		To replace a <code>&lt;textarea&gt;</code> element, place the following call at any point
+		after the <code>&lt;textarea&gt;</code> element or inside a <code>&lt;script&gt;</code> element located
+		in the <code>&lt;head&gt;</code> section of the page, in a <code>window.onload</code> event handler: 
+	</p>
+	<pre>CKEDITOR.replace( '<em>textarea_id</em>' );</pre>
+	<p>
+		Note that <code><em>textarea_id</em></code> in the code above is the <code>id</code> attribute of
+		the <code>&lt;textarea&gt;</code> element to be replaced.
+	</p>
+	</div>
+	
 	<!-- This <div> holds alert messages to be display in the sample page. -->
 	<div id="alerts">
@@ -33,5 +50,5 @@
 		<p>
 			<label for="editor1">
-				Editor 1:</label><br />
+				Editor 1:</label>
 			<textarea cols="80" id="editor1" name="editor1" rows="10">&lt;p&gt;This is some &lt;strong&gt;sample text&lt;/strong&gt;. You are using &lt;a href="http://ckeditor.com/"&gt;CKEditor&lt;/a&gt;.&lt;/p&gt;</textarea>
 			<script type="text/javascript">
@@ -51,5 +68,5 @@
 		<p>
 			<label for="editor2">
-				Editor 2:</label><br />
+				Editor 2:</label>
 			<textarea cols="80" id="editor2" name="editor2" rows="10">&lt;p&gt;This is some &lt;strong&gt;sample text&lt;/strong&gt;. You are using &lt;a href="http://ckeditor.com/"&gt;CKEditor&lt;/a&gt;.&lt;/p&gt;</textarea>
 			<script type="text/javascript">
@@ -74,5 +91,5 @@
 		<hr />
 		<p>
-			CKEditor - The text editor for Internet - <a href="http://ckeditor.com/">http://ckeditor.com</a>
+			CKEditor - The text editor for the Internet - <a href="http://ckeditor.com/">http://ckeditor.com</a>
 		</p>
 		<p id="copy">
Index: /CKEditor/trunk/_samples/sample.css
===================================================================
--- /CKEditor/trunk/_samples/sample.css	(revision 6335)
+++ /CKEditor/trunk/_samples/sample.css	(revision 6336)
@@ -4,8 +4,96 @@
 */
 
+html, body, h1, h2, h3, h4, h5, h6, div, span, blockquote, p, address, form, fieldset, img, ul, ol, dl, dt, dd, li, hr, table, td, th, strong, em, sup, sub, dfn, ins, del, q, cite, var, samp, code, kbd, tt, pre {
+	border: 0 none;
+	line-height: 1.5em;
+	margin: 0;
+	padding: 0;
+}
+
+body {
+	padding:10px 30px;	
+}
+
+input, textarea, select, option, optgroup, button, td, th {
+	font-size: 100%;
+}
+
+pre,
+code,
+kbd,
+samp,
+tt{
+  font-family: monospace,monospace;
+  font-size: 1em;
+}
+
+b, strong {
+	font-weight:bold;
+}
+
+i, cite, em, var, dfn, blockquote {
+	font-style:italic;
+}
+
+p, ul, ol, blockquote, address, form, table, pre, dl, h1, h2, h3, h4, h5, h6 {
+	margin-bottom:15px;
+}
+
+ul ul, ul ol, ol ul, ol ol {
+	margin-bottom:0;
+}
+
+ul {
+	list-style-type:disc;
+}
+
+ol {
+	list-style-type:decimal;
+}
+
+li {
+	margin-left:40px;
+}
+
+a {
+	text-decoration:none;
+}
+
+a:hover {
+	text-decoration:underline;
+}
+
+.clear {
+	clear:both;
+}
+
 fieldset
 {
 	margin: 0;
 	padding: 10px;
+}
+
+body, input, textarea {
+	color: #333333;
+	font-family: Arial, Helvetica, sans-serif;
+}
+
+body {
+	font-size: 75%;
+}
+
+a {
+	color:#189DE1;
+}
+
+h1 {
+	color:#0782C1;
+	font-size:200%;
+	font-weight:normal;
+}
+
+h2 {
+	color:#000000;
+	font-size:130%;
 }
 
@@ -21,5 +109,4 @@
 	border: 1px solid #D7D7D7;
 	overflow: auto;
-	margin: 0;
 	padding: 0.25em;
 }
@@ -80,2 +167,14 @@
 	word-wrap: break-word; /* IE */
 }
+
+.description {
+	border: 1px dotted #B7B7B7;
+	margin-bottom: 10px;
+	padding: 10px 10px 0;
+}
+
+label {
+	display: block;
+	margin-bottom:6px;
+}
+
Index: /CKEditor/trunk/_samples/sharedspaces.html
===================================================================
--- /CKEditor/trunk/_samples/sharedspaces.html	(revision 6335)
+++ /CKEditor/trunk/_samples/sharedspaces.html	(revision 6336)
@@ -6,5 +6,5 @@
 <html xmlns="http://www.w3.org/1999/xhtml">
 <head>
-	<title>Shared toolbars - CKEditor Sample</title>
+	<title>Shared Toolbars &mdash; CKEditor Sample</title>
 	<meta content="text/html; charset=utf-8" http-equiv="content-type" />
 	<!-- CKReleaser %REMOVE_LINE%
@@ -30,6 +30,28 @@
 <body>
 	<h1>
-		CKEditor Sample
+		CKEditor Sample &mdash; Shared Toolbars
 	</h1>
+	<div class="description">
+	<p>
+		This sample shows how to configure multiple CKEditor instances to share some parts of the interface.
+		You can choose to share the toolbar (<code>topSpace</code>), the elements path
+		(<code>bottomSpace</code>), or both.
+	</p>
+	<p>
+		CKEditor instances with shared spaces can be inserted with a JavaScript call using the following code: 
+	</p>
+	<pre>CKEDITOR.replace( '<em>textarea_id</em>',
+	{
+		<strong>sharedSpaces :
+		{
+			top : 'topSpace',
+			bottom : 'bottomSpace'
+		}</strong>
+	});</pre>
+	<p>
+		Note that <code><em>textarea_id</em></code> in the code above is the <code>id</code> attribute of
+		the <code>&lt;textarea&gt;</code> element to be replaced with CKEditor.
+	</p>
+	</div>
 	<!-- This <div> holds alert messages to be display in the sample page. -->
 	<div id="alerts">
@@ -47,20 +69,20 @@
 		<p>
 			<label for="editor1">
-				Editor 1 (uses the shared toolbar and element path):</label><br />
+				Editor 1 (uses the shared toolbar and elements path):</label>
 			<textarea cols="80" id="editor1" name="editor1" rows="10">&lt;p&gt;This is some &lt;strong&gt;sample text&lt;/strong&gt;. You are using &lt;a href="http://ckeditor.com/"&gt;CKEditor&lt;/a&gt;.&lt;/p&gt;</textarea>
 		</p>
 		<p>
 			<label for="editor2">
-				Editor 2 (uses the shared toolbar and element path):</label><br />
+				Editor 2 (uses the shared toolbar and elements path):</label>
 			<textarea cols="80" id="editor2" name="editor2" rows="10">&lt;p&gt;This is some &lt;strong&gt;sample text&lt;/strong&gt;. You are using &lt;a href="http://ckeditor.com/"&gt;CKEditor&lt;/a&gt;.&lt;/p&gt;</textarea>
 		</p>
 		<p>
 			<label for="editor3">
-				Editor 3 (uses the shared toolbar only):</label><br />
+				Editor 3 (uses the shared toolbar only):</label>
 			<textarea cols="80" id="editor3" name="editor3" rows="10">&lt;p&gt;This is some &lt;strong&gt;sample text&lt;/strong&gt;. You are using &lt;a href="http://ckeditor.com/"&gt;CKEditor&lt;/a&gt;.&lt;/p&gt;</textarea>
 		</p>
 		<p>
 			<label for="editor4">
-				Editor 4 (no shared spaces):</label><br />
+				Editor 4 (no shared spaces):</label>
 			<textarea cols="80" id="editor4" name="editor4" rows="10">&lt;p&gt;This is some &lt;strong&gt;sample text&lt;/strong&gt;. You are using &lt;a href="http://ckeditor.com/"&gt;CKEditor&lt;/a&gt;.&lt;/p&gt;</textarea>
 		</p>
@@ -74,5 +96,5 @@
 		<hr />
 		<p>
-			CKEditor - The text editor for Internet - <a href="http://ckeditor.com/">http://ckeditor.com</a>
+			CKEditor - The text editor for the Internet - <a href="http://ckeditor.com/">http://ckeditor.com</a>
 		</p>
 		<p id="copy">
Index: /CKEditor/trunk/_samples/skins.html
===================================================================
--- /CKEditor/trunk/_samples/skins.html	(revision 6335)
+++ /CKEditor/trunk/_samples/skins.html	(revision 6336)
@@ -6,5 +6,5 @@
 <html xmlns="http://www.w3.org/1999/xhtml">
 <head>
-	<title>Skins - CKEditor Sample</title>
+	<title>Skins &mdash; CKEditor Sample</title>
 	<meta content="text/html; charset=utf-8" http-equiv="content-type" />
 	<!-- CKReleaser %REMOVE_LINE%
@@ -18,6 +18,24 @@
 <body>
 	<h1>
-		CKEditor Sample
+		CKEditor Sample &mdash; Skins
 	</h1>
+	<div class="description">
+	<p>
+		This sample shows how to automatically replace <code>&lt;textarea&gt;</code> elements
+		with a CKEditor instance using a specific <a href="http://docs.cksource.com/ckeditor_api/symbols/CKEDITOR.config.html#.skin">skin</a>.
+	</p>
+	<p>
+		CKEditor with a specified skin (in this case, the "Office 2003" skin) is inserted with a JavaScript call using the following code:  
+	</p>
+	<pre>CKEDITOR.replace( '<em>textarea_id</em>',
+	{
+		<strong>skin : 'office2003'</strong>
+	});</pre>
+	<p>
+		Note that <code><em>textarea_id</em></code> in the code above is the <code>id</code> attribute of
+		the <code>&lt;textarea&gt;</code> element to be replaced.
+	</p>
+	</div>
+	
 	<!-- This <div> holds alert messages to be display in the sample page. -->
 	<div id="alerts">
@@ -31,6 +49,7 @@
 	</div>
 	<form action="sample_posteddata.php" method="post">
+	<h2>&quot;Kama&quot; skin</h2>
+	<p>The default skin used in CKEditor. No additional configuration is required.</p>
 		<p>
-			"Kama" skin:<br />
 			<textarea cols="80" id="editor_kama" name="editor_kama" rows="10">&lt;p&gt;This is some &lt;strong&gt;sample text&lt;/strong&gt;. You are using &lt;a href="http://ckeditor.com/"&gt;CKEditor&lt;/a&gt;.&lt;/p&gt;</textarea>
 			<script type="text/javascript">
@@ -45,6 +64,11 @@
 			</script>
 		</p>
+	<h2>&quot;Office 2003&quot; skin</h2>
+	<p>Use the following code to configure a CKEditor instance to use the "Office 2003" skin.</p>
+<pre>CKEDITOR.replace( '<em>textarea_id</em>',
+	{
+		<strong>skin : 'office2003'</strong>
+	});</pre>
 		<p>
-			"Office 2003" skin:<br />
 			<textarea cols="80" id="editor_office2003" name="editor_office2003" rows="10">&lt;p&gt;This is some &lt;strong&gt;sample text&lt;/strong&gt;. You are using &lt;a href="http://ckeditor.com/"&gt;CKEditor&lt;/a&gt;.&lt;/p&gt;</textarea>
 			<script type="text/javascript">
@@ -59,6 +83,10 @@
 			</script>
 		</p>
-		<p>
-			"V2" skin:<br />
+		<h2>&quot;V2&quot; skin</h2>
+		<p>Use the following code to configure a CKEditor instance to use the "V2" skin.</p>
+<pre>CKEDITOR.replace( '<em>textarea_id</em>',
+	{
+		<strong>skin : 'v2'</strong>
+	});</pre>
 			<textarea cols="80" id="editor_v2" name="editor_v2" rows="10">&lt;p&gt;This is some &lt;strong&gt;sample text&lt;/strong&gt;. You are using &lt;a href="http://ckeditor.com/"&gt;CKEditor&lt;/a&gt;.&lt;/p&gt;</textarea>
 			<script type="text/javascript">
@@ -72,10 +100,9 @@
 			//]]>
 			</script>
-		</p>
 	</form>
 	<div id="footer">
 		<hr />
 		<p>
-			CKEditor - The text editor for Internet - <a href="http://ckeditor.com/">http://ckeditor.com</a>
+			CKEditor - The text editor for the Internet - <a href="http://ckeditor.com/">http://ckeditor.com</a>
 		</p>
 		<p id="copy">
Index: /CKEditor/trunk/_samples/ui_color.html
===================================================================
--- /CKEditor/trunk/_samples/ui_color.html	(revision 6335)
+++ /CKEditor/trunk/_samples/ui_color.html	(revision 6336)
@@ -6,5 +6,5 @@
 <html xmlns="http://www.w3.org/1999/xhtml">
 <head>
-	<title>UI Color Setting Tool - CKEditor Sample</title>
+	<title>UI Color Picker &mdash; CKEditor Sample</title>
 	<meta content="text/html; charset=utf-8" http-equiv="content-type" />
 	<!-- CKReleaser %REMOVE_LINE%
@@ -18,6 +18,39 @@
 <body>
 	<h1>
-		CKEditor Sample
+		CKEditor Sample &mdash; UI Color Picker
 	</h1>
+	<div class="description">
+	<p>
+		This sample shows how to automatically replace <code>&lt;textarea&gt;</code> elements
+		with a CKEditor instance with an option to change the color of its user interface.
+	</p>
+	<h2>Setting the User Interface Color</h2>
+	<p>
+	To specify the color of the user interface, set the <code>uiColor</code> property:  
+	</p>
+	<pre>CKEDITOR.replace( '<em>textarea_id</em>',
+	{
+		<strong>uiColor: '#EE0000'</strong>
+	});</pre>
+	<p>
+		Note that <code><em>textarea_id</em></code> in the code above is the <code>id</code> attribute of
+		the <code>&lt;textarea&gt;</code> element to be replaced.
+	</p>
+	<h2>Enabling the Color Picker</h2>
+	<p>
+		If the <strong>uicolor</strong> plugin along with the dedicated <strong>UIColor</strong>
+		toolbar button is added to CKEditor, the user will also be able to pick the color of the
+		UI from the color palette available in the <strong>UI Color Picker</strong> dialog window.  
+	</p>
+	<p>
+		To insert a CKEditor instance with the <strong>uicolor</strong> plugin enabled,
+		use the following JavaScript call: 
+	</p>
+	<pre>CKEDITOR.replace( '<em>textarea_id</em>',
+	{
+		<strong>extraPlugins : 'uicolor',</strong>
+		toolbar : [ [ 'Bold', 'Italic' ], [ <strong>'UIColor'</strong> ] ]
+	});</pre>
+	</div>
 	<!-- This <div> holds alert messages to be display in the sample page. -->
 	<div id="alerts">
@@ -31,5 +64,10 @@
 	</div>
 	<p>
-		Click the UI Color Picker button to test your color preferences at runtime.</p>
+		Click the <strong>UI Color Picker</strong> button to test your color preferences at runtime.
+	</p>
+	<p>
+		The first editor instance includes the <strong>UI Color Picker</strong> toolbar button,
+		but the default UI color is not defined, so the editor uses the skin color.
+	</p>
 	<form action="sample_posteddata.php" method="post">
 	<p>
@@ -52,4 +90,8 @@
 		//]]>
 		</script>
+	</p>
+	<p>
+		The second editor instance includes the <strong>UI Color Picker</strong> toolbar button. The
+		default UI color was defined, so the skin color is not used.
 	</p>
 	<p>
@@ -81,5 +123,5 @@
 		<hr />
 		<p>
-			CKEditor - The text editor for Internet - <a href="http://ckeditor.com/">http://ckeditor.com</a>
+			CKEditor - The text editor for the Internet - <a href="http://ckeditor.com/">http://ckeditor.com</a>
 		</p>
 		<p id="copy">
Index: /CKEditor/trunk/_samples/ui_languages.html
===================================================================
--- /CKEditor/trunk/_samples/ui_languages.html	(revision 6335)
+++ /CKEditor/trunk/_samples/ui_languages.html	(revision 6336)
@@ -6,5 +6,5 @@
 <html xmlns="http://www.w3.org/1999/xhtml">
 <head>
-	<title>User Interface Globalization - CKEditor Sample</title>
+	<title>User Interface Globalization &mdash; CKEditor Sample</title>
 	<meta content="text/html; charset=utf-8" http-equiv="content-type" />
 	<!-- CKReleaser %REMOVE_LINE%
@@ -20,6 +20,37 @@
 <body>
 	<h1>
-		CKEditor Sample
+		CKEditor Sample &mdash; User Interface Languages
 	</h1>
+	<div class="description">
+	<p>
+		This sample shows how to automatically replace <code>&lt;textarea&gt;</code> elements
+		with a CKEditor instance with an option to change the language of its user interface.
+	</p>
+	<p>
+		It pulls the language list from CKEditor <code>_languages.js</code> file that contains the list of supported languages and creates
+		a drop-down list that lets the user change the UI language.
+	</p>
+	<p>
+	By default, CKEditor automatically localizes the editor to the language of the user.
+	The UI language can be controlled with two configuration options:
+	<a href="http://docs.cksource.com/ckeditor_api/symbols/CKEDITOR.config.html#.language">
+	<code>language</code></a> and <a href="http://docs.cksource.com/ckeditor_api/symbols/CKEDITOR.config.html#.defaultLanguage">
+	<code>defaultLanguage</code></a>. The <code>defaultLanguage</code> setting specifies the
+	default CKEditor language to be used when a localization suitable for user's settings is not available.
+	</p>
+	<p>
+	To specify the user interface language that will be used no matter what language is 
+	specified in user's browser or operating system, set the <code>language</code> property:  
+	</p>
+	<pre>CKEDITOR.replace( '<em>textarea_id</em>',
+	{
+		// Load the German interface.
+		<strong>language: 'de'</strong>
+	});</pre>
+	<p>
+		Note that <code><em>textarea_id</em></code> in the code above is the <code>id</code> attribute of
+		the <code>&lt;textarea&gt;</code> element to be replaced.
+	</p>
+	</div>
 	<!-- This <div> holds alert messages to be display in the sample page. -->
 	<div id="alerts">
@@ -50,5 +81,5 @@
 			</script>
 			<br />
-			<span style="color: #888888">(You may see strange characters if your system doesn't
+			<span style="color: #888888">(You may see strange characters if your system does not
 				support the selected language)</span>
 		</p>
@@ -98,5 +129,5 @@
 		<hr />
 		<p>
-			CKEditor - The text editor for Internet - <a href="http://ckeditor.com/">http://ckeditor.com</a>
+			CKEditor - The text editor for the Internet - <a href="http://ckeditor.com/">http://ckeditor.com</a>
 		</p>
 		<p id="copy">

Index: /CKEditor/trunk/_samples/php/events.php
===================================================================
--- /CKEditor/trunk/_samples/php/events.php	(revision 6335)
+++ /CKEditor/trunk/_samples/php/events.php	(revision 6336)
@@ -6,5 +6,5 @@
 <html xmlns="http://www.w3.org/1999/xhtml">
 <head>
-	<title>Sample - CKEditor</title>
+	<title>Adding Event Handlers &mdash; CKEditor Sample</title>
 	<meta content="text/html; charset=utf-8" http-equiv="content-type"/>
 	<link href="../sample.css" rel="stylesheet" type="text/css"/>
@@ -12,6 +12,36 @@
 <body>
 	<h1>
-		CKEditor Sample
+		CKEditor Sample &mdash; Adding Event Handlers
 	</h1>
+	<div class="description">
+	<p>
+		This sample shows how to add event handlers to CKEditor with PHP.
+	</p>
+	<p>
+		A snippet of the configuration code can be seen below; check the source code of this page for 
+		the full definition:
+	</p>
+	<pre>&lt;?php
+// Include the CKEditor class.
+include("ckeditor/ckeditor.php");
+
+// Create a class instance.
+$CKEditor = new CKEditor();
+
+// Path to the CKEditor directory.
+$CKEditor->basePath = '/ckeditor/';
+
+// The initial value to be displayed in the editor.
+$initialValue = 'This is some sample text.';
+
+// Add event handler, <em>instanceReady</em> is fired when editor is loaded.
+$CKEditor-><strong>addEventHandler</strong>('instanceReady', 'function (evt) {
+	alert("Loaded editor: " + evt.editor.name);
+}');
+
+// Create an editor instance.
+$CKEditor->editor("editor1", $initialValue);
+</pre>
+	</div>
 	<!-- This <div> holds alert messages to be display in the sample page. -->
 	<div id="alerts">
@@ -24,24 +54,19 @@
 		</noscript>
 	</div>
-	<!-- This <fieldset> holds the HTML that you will usually find in your pages. -->
-	<fieldset title="Output">
-		<legend>Output</legend>
-		<form action="../sample_posteddata.php" method="post">
-			<p>
-				<label>Editor 1:</label><br/>
-			</p>
+	<form action="../sample_posteddata.php" method="post">
+		<label>Editor 1:</label>
 <?php
 
 /**
  * Adds global event, will hide "Target" tab in Link dialog in all instances.
  */
 function CKEditorHideLinkTargetTab(&$CKEditor) {
 
 	$function = 'function (ev) {
 		// Take the dialog name and its definition from the event data
 		var dialogName = ev.data.name;
 		var dialogDefinition = ev.data.definition;
 
 		// Check if the definition is from the Link dialog.
 		if ( dialogName == "link" )
 			dialogDefinition.removeContents("target")
@@ -52,9 +77,9 @@
 
 /**
  * Adds global event, will notify about opened dialog.
  */
 function CKEditorNotifyAboutOpenedDialog(&$CKEditor) {
 	$function = 'function (evt) {
-		alert("Loading dialog: " + evt.data.name);
+		alert("Loading a dialog window: " + evt.data.name);
 	}';
 
@@ -62,14 +87,14 @@
 }
 
-// Include CKEditor class.
+// Include the CKEditor class.
 include("../../ckeditor.php");
 
-// Create class instance.
+// Create a class instance.
 $CKEditor = new CKEditor();
 
-// Set configuration option for all editors.
+// Set a configuration option for all editors.
 $CKEditor->config['width'] = 750;
 
-// Path to CKEditor directory, ideally instead of relative dir, use an absolute path:
+// Path to the CKEditor directory, ideally use an absolute path instead of a relative dir.
 //   $CKEditor->basePath = '/ckeditor/'
 // If not set, CKEditor will try to detect the correct path.
@@ -84,16 +109,15 @@
 }');
 
-// Create first instance.
+// Create the first instance.
 $CKEditor->editor("editor1", $initialValue);
 
-// Clear event handlers, instances that will be created later will not have
+// Clear event handlers. Instances that will be created later will not have
 // the 'instanceReady' listener defined a couple of lines above.
 $CKEditor->clearEventHandlers();
 ?>
-			<p>
-				<label>Editor 2:</label><br/>
-			</p>
+		<br />
+		<label>Editor 2:</label>
 <?php
-// Configuration that will be used only by the second editor.
+// Configuration that will only be used by the second editor.
 $config['width'] = '600';
 $config['toolbar'] = 'Basic';
@@ -103,5 +127,5 @@
 CKEditorNotifyAboutOpenedDialog($CKEditor);
 
-// Event that will be handled only by the second editor.
+// Event that will only be handled by the second editor.
 // Instead of calling addEventHandler(), events may be passed as an argument.
 $events['instanceReady'] = 'function (evt) {
@@ -109,16 +133,15 @@
 }';
 
-// Create second instance.
+// Create the second instance.
 $CKEditor->editor("editor2", $initialValue, $config, $events);
 ?>
-			<p>
-				<input type="submit" value="Submit"/>
-			</p>
-		</form>
-	</fieldset>
+		<p>
+			<input type="submit" value="Submit"/>
+		</p>
+	</form>
 	<div id="footer">
 		<hr />
 		<p>
-			CKEditor - The text editor for Internet - <a href="http://ckeditor.com/">http://ckeditor.com</a>
+			CKEditor - The text editor for the Internet - <a href="http://ckeditor.com/">http://ckeditor.com</a>
 		</p>
 		<p id="copy">
@@ -24,24 +54,19 @@
 
 /**
- * Adds global event, will hide "Target" tab in Link dialog in all instances.
+ * Adds a global event, will hide the "Target" tab in the "Link" dialog window in all instances.
  */
 function CKEditorHideLinkTargetTab(&$CKEditor) {
@@ -24,24 +54,19 @@
 
 	$function = 'function (ev) {
-		// Take the dialog name and its definition from the event data
+		// Take the dialog window name and its definition from the event data.
 		var dialogName = ev.data.name;
 		var dialogDefinition = ev.data.definition;
@@ -24,24 +54,19 @@
 		var dialogDefinition = ev.data.definition;
 
-		// Check if the definition is from the Link dialog.
+		// Check if the definition comes from the "Link" dialog window.
 		if ( dialogName == "link" )
 			dialogDefinition.removeContents("target")
@@ -52,9 +77,9 @@
 
 /**
- * Adds global event, will notify about opened dialog.
+ * Adds a global event, will notify about an open dialog window.
  */
 function CKEditorNotifyAboutOpenedDialog(&$CKEditor) {
Index: /CKEditor/trunk/_samples/php/replace.php
===================================================================
--- /CKEditor/trunk/_samples/php/replace.php	(revision 6335)
+++ /CKEditor/trunk/_samples/php/replace.php	(revision 6336)
@@ -6,5 +6,5 @@
 <html xmlns="http://www.w3.org/1999/xhtml">
 <head>
-	<title>Sample - CKEditor</title>
+	<title>Replace Selected Textarea Elements &mdash; CKEditor Sample</title>
 	<meta content="text/html; charset=utf-8" http-equiv="content-type"/>
 	<link href="../sample.css" rel="stylesheet" type="text/css"/>
@@ -12,6 +12,34 @@
 <body>
 	<h1>
-		CKEditor Sample
+		CKEditor Sample &mdash;  Replace Selected Textarea Elements Using PHP Code 
 	</h1>
+	<div class="description">
+	<p>
+		This sample shows how to replace a selected <code>&lt;textarea&gt;</code> element
+		with a CKEditor instance by using PHP code.
+	</p>
+	<p>
+		To replace a <code>&lt;textarea&gt;</code> element, place the following call at any point
+		after the <code>&lt;textarea&gt;</code> element: 
+	</p>
+	<pre>
+&lt;?php
+// Include the CKEditor class.
+include_once "ckeditor/ckeditor.php";
+
+// Create a class instance.
+$CKEditor = new CKEditor();
+
+// Path to the CKEditor directory.
+$CKEditor->basePath = '/ckeditor/';
+
+// Replace a textarea element with an id (or name) of "textarea_id".
+$CKEditor->replace("textarea_id");
+?&gt;</pre>
+	<p>
+		Note that <code><em>textarea_id</em></code> in the code above is the <code>id</code> attribute of
+		the <code>&lt;textarea&gt;</code> element to be replaced.
+	</p>
+	</div>
 	<!-- This <div> holds alert messages to be display in the sample page. -->
 	<div id="alerts">
@@ -24,22 +52,18 @@
 		</noscript>
 	</div>
-	<!-- This <fieldset> holds the HTML that you will usually find in your pages. -->
-	<fieldset title="Output">
-		<legend>Output</legend>
-		<form action="../sample_posteddata.php" method="post">
-			<p>
-				<label for="editor1">
-					Editor 1:</label><br/>
-				<textarea cols="80" id="editor1" name="editor1" rows="10">&lt;p&gt;This is some &lt;strong&gt;sample text&lt;/strong&gt;. You are using &lt;a href="http://ckeditor.com/"&gt;CKEditor&lt;/a&gt;.&lt;/p&gt;</textarea>
-			</p>
-			<p>
-				<input type="submit" value="Submit"/>
-			</p>
-		</form>
-	</fieldset>
+	<form action="../sample_posteddata.php" method="post">
+		<p>
+			<label for="editor1">
+				Editor 1:</label>
+			<textarea cols="80" id="editor1" name="editor1" rows="10">&lt;p&gt;This is some &lt;strong&gt;sample text&lt;/strong&gt;. You are using &lt;a href="http://ckeditor.com/"&gt;CKEditor&lt;/a&gt;.&lt;/p&gt;</textarea>
+		</p>
+		<p>
+			<input type="submit" value="Submit"/>
+		</p>
+	</form>
 	<div id="footer">
 		<hr />
 		<p>
-			CKEditor - The text editor for Internet - <a href="http://ckeditor.com/">http://ckeditor.com</a>
+			CKEditor - The text editor for the Internet - <a href="http://ckeditor.com/">http://ckeditor.com</a>
 		</p>
 		<p id="copy">
@@ -49,13 +73,13 @@
 	</div>
 	<?php
-	// Include CKEditor class.
+	// Include the CKEditor class.
 	include_once "../../ckeditor.php";
-	// Create class instance.
+	// Create a class instance.
 	$CKEditor = new CKEditor();
-	// Path to CKEditor directory, ideally instead of relative dir, use an absolute path:
+	// Path to the CKEditor directory, ideally use an absolute path instead of a relative dir.
 	//   $CKEditor->basePath = '/ckeditor/'
 	// If not set, CKEditor will try to detect the correct path.
 	$CKEditor->basePath = '../../';
 	// Replace textarea with id (or name) "editor1".
 	$CKEditor->replace("editor1");
 	?>
@@ -49,13 +73,13 @@
 	// If not set, CKEditor will try to detect the correct path.
 	$CKEditor->basePath = '../../';
-	// Replace textarea with id (or name) "editor1".
+	// Replace a textarea element with an id (or name) of "editor1".
 	$CKEditor->replace("editor1");
 	?>
Index: /CKEditor/trunk/_samples/php/replaceall.php
===================================================================
--- /CKEditor/trunk/_samples/php/replaceall.php	(revision 6335)
+++ /CKEditor/trunk/_samples/php/replaceall.php	(revision 6336)
@@ -6,5 +6,5 @@
 <html xmlns="http://www.w3.org/1999/xhtml">
 <head>
-	<title>Sample - CKEditor</title>
+	<title>Replace All Textarea Elements &mdash; CKEditor Sample</title>
 	<meta content="text/html; charset=utf-8" http-equiv="content-type"/>
 	<link href="../sample.css" rel="stylesheet" type="text/css"/>
@@ -12,7 +12,31 @@
 <body>
 	<h1>
-		CKEditor Sample
+		CKEditor Sample &mdash; Replace All Textarea Elements Using PHP Code
 	</h1>
-	<!-- This <div> holds alert messages to be display in the sample page. -->
+	<div class="description">
+	<p>
+		This sample shows how to replace all <code>&lt;textarea&gt;</code> elements
+		with CKEditor by using PHP code.
+	</p>
+	<p>
+		To replace all <code>&lt;textarea&gt;</code> elements, place the following call at any point
+		after the last <code>&lt;textarea&gt;</code> element: 
+	</p>
+	<pre>
+&lt;?php
+// Include the CKEditor class.
+include("ckeditor/ckeditor.php");
+
+// Create a class instance.
+$CKEditor = new CKEditor();
+
+// Path to the CKEditor directory.
+$CKEditor->basePath = '/ckeditor/';
+
+// Replace all textarea elements with CKEditor.
+$CKEditor->replaceAll();
+?&gt;</pre>
+	</div>
+	<!-- This <div> holds alert messages to be displayed in the sample page. -->
 	<div id="alerts">
 		<noscript>
@@ -24,27 +48,23 @@
 		</noscript>
 	</div>
-	<!-- This <fieldset> holds the HTML that you will usually find in your pages. -->
-	<fieldset title="Output">
-		<legend>Output</legend>
-		<form action="../sample_posteddata.php" method="post">
-			<p>
-				<label for="editor1">
-					Editor 1:</label><br/>
-				<textarea cols="80" id="editor1" name="editor1" rows="10">&lt;p&gt;This is some &lt;strong&gt;sample text&lt;/strong&gt;. You are using &lt;a href="http://ckeditor.com/"&gt;CKEditor&lt;/a&gt;.&lt;/p&gt;</textarea>
-			</p>
-			<p>
-				<label for="editor2">
-					Editor 2:</label><br/>
-				<textarea cols="80" id="editor2" name="editor2" rows="10">&lt;p&gt;This is some &lt;strong&gt;sample text&lt;/strong&gt;. You are using &lt;a href="http://ckeditor.com/"&gt;CKEditor&lt;/a&gt;.&lt;/p&gt;</textarea>
-			</p>
-			<p>
-				<input type="submit" value="Submit"/>
-			</p>
-		</form>
-	</fieldset>
+	<form action="../sample_posteddata.php" method="post">
+		<p>
+			<label for="editor1">
+				Editor 1:</label>
+			<textarea cols="80" id="editor1" name="editor1" rows="10">&lt;p&gt;This is some &lt;strong&gt;sample text&lt;/strong&gt;. You are using &lt;a href="http://ckeditor.com/"&gt;CKEditor&lt;/a&gt;.&lt;/p&gt;</textarea>
+		</p>
+		<p>
+			<label for="editor2">
+				Editor 2:</label>
+			<textarea cols="80" id="editor2" name="editor2" rows="10">&lt;p&gt;This is some &lt;strong&gt;sample text&lt;/strong&gt;. You are using &lt;a href="http://ckeditor.com/"&gt;CKEditor&lt;/a&gt;.&lt;/p&gt;</textarea>
+		</p>
+		<p>
+			<input type="submit" value="Submit"/>
+		</p>
+	</form>
 	<div id="footer">
 		<hr />
 		<p>
-			CKEditor - The text editor for Internet - <a href="http://ckeditor.com/">http://ckeditor.com</a>
+			CKEditor - The text editor for the Internet - <a href="http://ckeditor.com/">http://ckeditor.com</a>
 		</p>
 		<p id="copy">
@@ -54,13 +74,13 @@
 	</div>
 	<?php
-	// Include CKEditor class.
+	// Include the CKEditor class.
 	include("../../ckeditor.php");
-	// Create class instance.
+	// Create a class instance.
 	$CKEditor = new CKEditor();
-	// Path to CKEditor directory, ideally instead of relative dir, use an absolute path:
+	// Path to the CKEditor directory, ideally use an absolute path instead of a relative dir.
 	//   $CKEditor->basePath = '/ckeditor/'
 	// If not set, CKEditor will try to detect the correct path.
 	$CKEditor->basePath = '../../';
 	// Replace all textareas with CKEditor.
 	$CKEditor->replaceAll();
 	?>
@@ -54,13 +74,13 @@
 	// If not set, CKEditor will try to detect the correct path.
 	$CKEditor->basePath = '../../';
-	// Replace all textareas with CKEditor.
+	// Replace all textarea elements with CKEditor.
 	$CKEditor->replaceAll();
 	?>